@@ -1,9 +1,10 @@
 """
 Inverse square root implementations. (Implementation from Wikipedia and math.h)
 """
-
-from ._sqrt import coarse_inv_sqrt as c
-from ._sqrt import fined_inv_sqrt as f
+import logging
+logger = logging.getLogger('quake_inverse_sq')
+from ._sqrt import coarse_inv_sqrt as __c
+from ._sqrt import fined_inv_sqrt as __f
 
 def coarse_inv_sqrt(number:float) -> float:
     """
@@ -13,7 +14,7 @@ def coarse_inv_sqrt(number:float) -> float:
         raise ZeroDivisionError
     elif not isinstance(number, (float,int)):
         raise ValueError("Inappropriate argument value")
-    return c(number)
+    return __c(number)
 
 def fined_inv_sqrt(number: float) -> float:
     """
@@ -23,4 +24,5 @@ def fined_inv_sqrt(number: float) -> float:
         raise ZeroDivisionError
     elif not isinstance(number, (float,int)):
         raise ValueError("Inappropriate argument value")
-    return f(number)
\ No newline at end of file
+    return __f(number)
+
